==> spip_4.2.9+dfsg.orig.tar.xz: plugins-dist/dump/lang/dump_km.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/dump?lang_cible=km
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_restaurer_base' => 'ធ្វើអោយដូចដើម ​ឃ្លាំង​ទិន្នន័យ​',

	// I
	'info_restauration_sauvegarde' => 'ការ​កែ​លំអ​កម្មវិធី​ថត​ទុក​នូវ​ឯកសារ (backup) @archive@', # MODIF
	'info_sauvegarde' => 'ច្បាប់ចំលង',
	'info_sauvegarde_reussi_02' => 'ឃ្លាំងទិន្នន័យ ​ត្រូវ​បាន​បង្កើត ជាច្បាប់ចំលង ក្នុង @archive@។ អ្នក​អាច',
	'info_sauvegarde_reussi_03' => 'ត្រលប់ ទៅ ការគ្រប់គ្រង',
	'info_sauvegarde_reussi_04' => 'នៃសៃថ៍ របស់អ្នក។',

	// T
	'texte_admin_tech_01' => 'ជម្រើស​នេះ​អនុញ្ញាត​ឱ្យ​លោក​អ្នករក្សា​ទុក​នូវ​ខ្លឹមសារ​ទិន្នន័យ​នៅ​ក្នុង​ហ្វា​ល​ដែល​រក្សា​ទុក​នៅ​ក្នុង​ថត (directory) @dossier@។ ដូច​គ្នា​នេះ​ដែរ សូម​ចង​ចាំ​ត្រូវ​បើក @img@ ទាំងមូល ដែល​មាន​រូបភាព និង​ឯកសារ​ដែល​ត្រូវ​ប្រើប្រាស់​នៅ​ក្នុង​អត្ថបទ និង​ផ្នែក​។',
	'texte_admin_tech_02' => 'ប្រយត្ន៖ ការបង្កើតច្បាប់ចំលងនេះ នឹងអាចស្តារ ត្រឹមក្នុងមួយវ៉ែបសៃថ៍ មានកំណែ SPIP ដូចគ្នា។ ចឹងគ្មានត្រូវ ជាពិសេស  " លុបសំអាត ឃ្លាំងទិន្នន័យ " ដោយសង្ឃឹម តំលើងឡើងវិញ ច្បាប់ចំលង ក្រោយការបន្ទាន់សម័យ... សូមពិនិត្យ <a href="@spipnet@">កំរងឯកសារ របស់ SPIP</a>។ ។', # MODIF
	'texte_restaurer_base' => 'ស្តារ ខ្លឹមសារ នៃច្បាប់ចំលងទិន្នន័យ',
	'texte_restaurer_sauvegarde' => 'ជំរើសនេះ អនុញ្ញាតខ្ញុំ​ ស្តារមួយច្បាប់ចំលង នៃមូលដ្ឋានទិន្នន័យ។ ដើម្បីសំរេចចឹង, ឯកសារ មានផ្ទុកច្បាប់ចំលង គួរតែត្រូវបានតំកល់ទុក ក្នុងថត​  @dossier@។
 ត្រូវតែប្រយត្ន ជាមួយមុខងារនេះ៖ <b>គ្រប់បំលាសប្តូរ ឬ គ្រប់ការបាត់បង់ គ្មានអាចត្រលប់ក្រោយ។</b>  ', # MODIF
	'texte_sauvegarde' => 'ថត​ទុក​នូវ​ខ្លឹមសារ​សំណុំ​ទិន្នន័យ',
	'texte_sauvegarde_base' => 'ថត​ទុក​នូវ​សំណុំ​ទិន្នន័យ'
);

==> spip_4.4.6+dfsg.orig.tar.xz: plugins-dist/dump/lang/dump_km.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/dump?lang_cible=km
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_restaurer_base' => 'ធ្វើអោយដូចដើម ​ឃ្លាំង​ទិន្នន័យ​',

	// I
	'info_restauration_sauvegarde' => 'ការ​កែ​លំអ​កម្មវិធី​ថត​ទុក​នូវ​ឯកសារ (backup) @archive@', # MODIF
	'info_sauvegarde' => 'ច្បាប់ចំលង',
	'info_sauvegarde_reussi_02' => 'ឃ្លាំងទិន្នន័យ ​ត្រូវ​បាន​បង្កើត ជាច្បាប់ចំលង ក្នុង @archive@។ អ្នក​អាច',
	'info_sauvegarde_reussi_03' => 'ត្រលប់ ទៅ ការគ្រប់គ្រង',
	'info_sauvegarde_reussi_04' => 'នៃសៃថ៍ របស់អ្នក។',

	// T
	'texte_admin_tech_01' => 'ជម្រើស​នេះ​អនុញ្ញាត​ឱ្យ​លោក​អ្នករក្សា​ទុក​នូវ​ខ្លឹមសារ​ទិន្នន័យ​នៅ​ក្នុង​ហ្វា​ល​ដែល​រក្សា​ទុក​នៅ​ក្នុង​ថត (directory) @dossier@។ ដូច​គ្នា​នេះ​ដែរ សូម​ចង​ចាំ​ត្រូវ​បើក @img@ ទាំងមូល ដែល​មាន​រូបភាព និង​ឯកសារ​ដែល​ត្រូវ​ប្រើប្រាស់​នៅ​ក្នុង​អត្ថបទ និង​ផ្នែក​។',
	'texte_admin_tech_02' => 'ប្រយត្ន៖ ការបង្កើតច្បាប់ចំលងនេះ នឹងអាចស្តារ ត្រឹមក្នុងមួយវ៉ែបសៃថ៍ មានកំណែ SPIP ដូចគ្នា។ ចឹងគ្មានត្រូវ ជាពិសេស  " លុបសំអាត ឃ្លាំងទិន្នន័យ " ដោយសង្ឃឹម តំលើងឡើងវិញ ច្បាប់ចំលង ក្រោយការបន្ទាន់សម័យ... សូមពិនិត្យ <a href="@spipnet@">កំរងឯកសារ របស់ SPIP</a>។ ។', # MODIF
	'texte_restaurer_base' => 'ស្តារ ខ្លឹមសារ នៃច្បាប់ចំលងទិន្នន័យ',
	'texte_restaurer_sauvegarde' => 'ជំរើសនេះ អនុញ្ញាតខ្ញុំ​ ស្តារមួយច្បាប់ចំលង នៃមូលដ្ឋានទិន្នន័យ។ ដើម្បីសំរេចចឹង, ឯកសារ មានផ្ទុកច្បាប់ចំលង គួរតែត្រូវបានតំកល់ទុក ក្នុងថត​  @dossier@។
 ត្រូវតែប្រយត្ន ជាមួយមុខងារនេះ៖ <b>គ្រប់បំលាសប្តូរ ឬ គ្រប់ការបាត់បង់ គ្មានអាចត្រលប់ក្រោយ។</b>  ', # MODIF
	'texte_sauvegarde' => 'ថត​ទុក​នូវ​ខ្លឹមសារ​សំណុំ​ទិន្នន័យ',
	'texte_sauvegarde_base' => 'ថត​ទុក​នូវ​សំណុំ​ទិន្នន័យ',
];
